pub struct ReadOnlyView<K, V, S = RandomState> { /* private fields */ }Expand description
A read-only view into a DashMap. Allows to obtain raw references to the stored values.
Implementations
Sourceimpl<K, V, S> ReadOnlyView<K, V, S>
impl<K, V, S> ReadOnlyView<K, V, S>
Sourcepub fn into_inner(self) -> DashMap<K, V, S>
pub fn into_inner(self) -> DashMap<K, V, S>
Consumes this ReadOnlyView, returning the underlying DashMap.
Sourceimpl<'a, K, V, S> ReadOnlyView<K, V, S>
impl<'a, K, V, S> ReadOnlyView<K, V, S>
Sourcepub fn capacity(&self) -> usize
pub fn capacity(&self) -> usize
Returns the number of elements the map can hold without reallocating.
Sourcepub fn contains_key<Q>(&'a self, key: &Q) -> bool
pub fn contains_key<Q>(&'a self, key: &Q) -> bool
Returns true if the map contains a value for the specified key.
Sourcepub fn get<Q>(&'a self, key: &Q) -> Option<&'a V>
pub fn get<Q>(&'a self, key: &Q) -> Option<&'a V>
Returns a reference to the value corresponding to the key.
Sourcepub fn get_key_value<Q>(&'a self, key: &Q) -> Option<(&'a K, &'a V)>
pub fn get_key_value<Q>(&'a self, key: &Q) -> Option<(&'a K, &'a V)>
Returns the key-value pair corresponding to the supplied key.
Sourcepub fn iter(&'a self) -> impl Iterator<Item = (&'a K, &'a V)> + 'a
pub fn iter(&'a self) -> impl Iterator<Item = (&'a K, &'a V)> + 'a
An iterator visiting all key-value pairs in arbitrary order. The iterator element type is (&'a K, &'a V).