AnySend

Trait AnySend 

pub trait AnySend: Any + Send { }
Represents a type that can be dynamically downcast and is safe to send across threads.

This trait combines the capabilities of Any and Send, ensuring that types implementing it can be safely sent across thread boundaries.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<T: Any + Send> AnySend for T

Implements AnySend for types that are Any and Send.

This trait signifies that a type can be safely sent across thread boundaries.