pub struct ArcRwLockStream(/* private fields */);Implementations
Sourceimpl ArcRwLockStream
impl ArcRwLockStream
Sourcepub fn from_stream(stream: TcpStream) -> Self
pub fn from_stream(stream: TcpStream) -> Self
Sourcepub async fn read(&self) -> RwLockReadGuardTcpStream<'_>
pub async fn read(&self) -> RwLockReadGuardTcpStream<'_>
Returns a reference to the inner TcpStream.
This method acquires a read lock on the underlying stream, allowing shared access to the TCP stream while preventing concurrent writes.
Returns
Returns a read guard that provides shared access to the TCP stream
Sourcepub async fn send(&self, data: &ResponseData) -> ResponseResult
pub async fn send(&self, data: &ResponseData) -> ResponseResult
Sourcepub async fn send_body_with_websocket_flag(
&self,
body: &ResponseBody,
is_websocket: bool,
) -> ResponseResult
pub async fn send_body_with_websocket_flag( &self, body: &ResponseBody, is_websocket: bool, ) -> ResponseResult
Sourcepub async fn send_body(&self, body: &ResponseBody) -> ResponseResult
pub async fn send_body(&self, body: &ResponseBody) -> ResponseResult
Sourcepub async fn send_websocket_body(&self, body: &ResponseBody) -> ResponseResult
pub async fn send_websocket_body(&self, body: &ResponseBody) -> ResponseResult