pub struct CookieBuilder { /* private fields */ }Expand description
A builder for constructing HTTP cookies with various attributes.
Implementations
Sourceimpl CookieBuilder
impl CookieBuilder
Sourcepub fn secure(&mut self) -> &mut Self
pub fn secure(&mut self) -> &mut Self
Sets the secure flag for the cookie.
When set to true, the cookie will only be sent over HTTPS connections.
Returns
- The CookieBuilder instance for method chaining.
Sourcepub fn http_only(&mut self) -> &mut Self
pub fn http_only(&mut self) -> &mut Self
Sets the HttpOnly flag for the cookie.
When set to true, the cookie will be inaccessible to JavaScript.
Returns
- The CookieBuilder instance for method chaining.