pub struct WebSocketFrame { /* private fields */ }Expand description
Represents a decoded WebSocket frame
Implementations
Sourceimpl WebSocketFrame
impl WebSocketFrame
Sourcepub fn decode_websocket_frame_with_length(
data: &[u8],
) -> WebsocketFrameWithLengthOption
pub fn decode_websocket_frame_with_length( data: &[u8], ) -> WebsocketFrameWithLengthOption
Sourcepub fn create_response_frame_list(body: &ResponseBody) -> Vec<ResponseBody> ⓘ
pub fn create_response_frame_list(body: &ResponseBody) -> Vec<ResponseBody> ⓘ
create_response_frame_list
body: A reference to a response body (payload) as a byte slice.- Returns: A vector of response bodies (frames) representing the framed data.
Sourcepub fn sha1(data: &[u8]) -> [u8; 20]
pub fn sha1(data: &[u8]) -> [u8; 20]
sha1
data: A byte slice containing the input data to be hashed.- Returns: A 20-byte array representing the SHA-1 hash of the input data.
Sourcepub fn generate_accept_key(key: &str) -> String
pub fn generate_accept_key(key: &str) -> String
generate_accept_key
key: A string slice containing the client-provided key.- Returns: A string representing the generated WebSocket accept key.
Sourcepub fn base64_encode(data: &[u8]) -> String
pub fn base64_encode(data: &[u8]) -> String
base64_encode
data: A byte slice containing the data to encode in base64.- Returns: A string with the base64 encoded representation of the input data.
Sourcepub fn opcode_is_continuation(&self) -> bool
pub fn opcode_is_continuation(&self) -> bool
Sourcepub fn opcode_is_text(&self) -> bool
pub fn opcode_is_text(&self) -> bool
Sourcepub fn opcode_is_binary(&self) -> bool
pub fn opcode_is_binary(&self) -> bool
Sourcepub fn opcode_is_close(&self) -> bool
pub fn opcode_is_close(&self) -> bool
Sourcepub fn opcode_is_ping(&self) -> bool
pub fn opcode_is_ping(&self) -> bool
Sourcepub fn opcode_is_pong(&self) -> bool
pub fn opcode_is_pong(&self) -> bool
Sourcepub fn opcode_is_reserved(&self) -> bool
pub fn opcode_is_reserved(&self) -> bool
Sourceimpl WebSocketFrame
impl WebSocketFrame
pub fn get_fin(&self) -> &bool
pub fn get_opcode(&self) -> &WebSocketOpcode
pub fn get_mask(&self) -> &bool
pub fn get_payload_data(&self) -> &Vec<u8> ⓘ