pub trait Lifetime {
// Required methods
unsafe fn leak(&self) -> &'static Self;
unsafe fn leak_mut(&self) -> &'static mut Self;
}Expand description
Trait for types that can be converted to a 'static reference.
This trait provides a way to obtain a 'static reference or mutable reference from
a reference to Self, enabling safe lifetime extension for
certain use cases where the object is known to live for the entire
program duration.
Required Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.